@@ -44,12 +44,12 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.0.0"
+#define SUNDIALS_VERSION "7.1.0"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 0
+#define SUNDIALS_VERSION_MINOR 1
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
-#define SUNDIALS_GIT_VERSION ""
+#define SUNDIALS_GIT_VERSION "v7.1.0"
 
 
 /* ------------------------------------------------------------------
@@ -57,9 +57,10 @@
  * -----------------------------------------------------------------*/
 
 #define SUNDIALS_C_COMPILER_HAS_BUILTIN_EXPECT
-/* #undef SUNDIALS_C_COMPILER_HAS_ATTRIBUTE_ASSUME */
+#define SUNDIALS_C_COMPILER_HAS_ATTRIBUTE_ASSUME
 /* #undef SUNDIALS_C_COMPILER_HAS_BUILTIN_ASSUME */
 /* #undef SUNDIALS_C_COMPILER_HAS_ASSUME */
+#define SUNDIALS_C_COMPILER_HAS_ATTRIBUTE_UNUSED
 
 /* Define precision of SUNDIALS data type 'sunrealtype'
  * Depending on the precision level, one of the following
@@ -105,8 +106,8 @@
 
 /* Build metadata */
 #define SUN_C_COMPILER "GNU"
-#define SUN_C_COMPILER_VERSION "12.1.0"
-#define SUN_C_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection"
+#define SUN_C_COMPILER_VERSION "14.1.1"
+#define SUN_C_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection"
 
 #define SUN_CXX_COMPILER ""
 #define SUN_CXX_COMPILER_VERSION ""
@@ -118,8 +119,8 @@
 
 #define SUN_BUILD_TYPE "RelWithDebInfo"
 
-#define SUN_JOB_ID "20240501114602"
-#define SUN_JOB_START_TIME "20240501114602"
+#define SUN_JOB_ID "20240621111738"
+#define SUN_JOB_START_TIME "20240621111738"
 
 #define SUN_TPL_LIST "MPI;OPENMP;KLU;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
@@ -220,7 +221,7 @@
 /* #undef SUNDIALS_GINKGO_BACKENDS_HIP */
 /* #undef SUNDIALS_GINKGO_BACKENDS_OMP */
 /* #undef SUNDIALS_GINKGO_BACKENDS_REF */
-/* #undef SUNDIALS_GINKGO_BACKENDS_DPCPP */
+/* #undef SUNDIALS_GINKGO_BACKENDS_SYCL */
 
 /* MAGMA backends */
 /* #undef SUNDIALS_MAGMA_BACKENDS_CUDA */
